@@ -4,7 +4,7 @@
 
 #include <klistview.h>
 #include <string>
-#include "stringlist.h"
+#include "kmysqladmin/helpers/stringlist.h"
 
 class TabView : public KListView
 {
