@@ -1,6 +1,6 @@
 // -*-Mode: C++;-*-
 /*
- * $Id: TextInput.h,v 2.2 1999/11/28 15:40:10 ral Exp $;
+ * $Id: TextInput.h,v 2.3 2001/04/08 12:24:47 ral Exp $;
  * Header file for CTextInput
  */
 #ifndef CTextInput_included
@@ -19,7 +19,7 @@ public:
 
 protected slots:
     void accept_field();
-    void inputChanged(const char*);
+    void inputChanged(const QString&);
 
 };
 #endif // CTextInput_included
