@@ -1,5 +1,5 @@
 /*
- * $Id: TextInputData.h,v 2.1 1999/03/09 01:03:59 ral Exp $
+ * $Id: TextInputData.h,v 2.2 2001/04/08 12:24:47 ral Exp $
  */
 
 #ifndef CTextInputData_included
@@ -29,7 +29,7 @@ public slots:
 
 protected slots:
 
-    virtual void inputChanged(const char*);
+    virtual void inputChanged(const QString&);
     virtual void accept_field();
 
 protected:
