@@ -8,13 +8,13 @@
 #include "my_sql.h"
 #include "globals.h"
 #include "stringres.h"
-#include "settings.h"
+#include "kmysqladmin/setup/settings.h"
 #include "qlistview.h"
 #include "klocale.h"
 #include "qpushbutton.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: ThreadView.cpp,v 2.13 2001/04/29 11:14:07 ral Exp $";
+static const char rcsid[]="$Id: ThreadView.cpp,v 2.14 2003/02/04 00:08:53 ral Exp $";
 //const char*threadview_rcs(){return rcsid;}
 #endif
 
