@@ -1,6 +1,6 @@
 // -*-Mode: C++;-*- 
 /*
- * $Id: ThreadView.h,v 2.5 2001/04/08 12:24:47 ral Exp $
+ * $Id: ThreadView.h,v 2.6 2003/02/04 00:08:53 ral Exp $
  * Include file for the thread-view-object
  */
 
@@ -9,7 +9,7 @@
 
 #include "ListViewData.h"
 #include "qtimer.h"
-#include "smart_pointer.h"
+#include "helpers/smart_pointer.h"
 
 class CMySql;
 
