@@ -16,7 +16,7 @@
  ***************************************************************************/
 
 #ifndef rcsid
-static const char rcsid[]="$Id: converter.cpp,v 2.8 2000/10/21 00:13:36 ral Exp $";
+static const char rcsid[]="$Id: converter.cpp,v 2.9 2003/02/04 00:08:53 ral Exp $";
 //const char*converter_rcs(){return rcsid;}
 #endif
 
@@ -30,7 +30,7 @@ static const char rcsid[]="$Id: converter.cpp,v 2.8 2000/10/21 00:13:36 ral Exp
 
 /** Constructor */
 CConverter::CConverter()
-	:refCounter()
+	:ref_count()
 {
     count = 0;
 }
