@@ -1,7 +1,7 @@
 // -*-Mode: C++;-*- 
 
 /*
- * $Id: deltabledlg.h,v 2.7 2001/04/16 13:01:09 ral Exp $
+ * $Id: deltabledlg.h,v 2.8 2003/02/04 00:08:53 ral Exp $
  * Include file for delete table dlg
  */
 
@@ -9,8 +9,8 @@
 #define CDeleteTableDlg_included
 
 #include "deltabledata.h"
-#include "stringlist.h"
-#include "smart_pointer.h"
+#include "kmysqladmin/helpers/stringlist.h"
+#include "kmysqladmin/helpers/smart_pointer.h"
 
 class CMySql;
 
