@@ -2,32 +2,34 @@
 
 
 CEdit::CEdit(QWidget*parent,const char*name)
-    :QMultiLineEdit(parent,name)
+    :QTextEdit(parent,name)
 {
     setFocusPolicy(QWidget::StrongFocus);
+    //    setTextFormat(Qt::PlainText);
+    //    setTextFormat(Qt::RichText);
+    setWordWrap(QTextEdit::NoWrap);
     setText("");
     setReadOnly(false);
 }
 
 CEdit::~CEdit()
 {
-    //    QMultiLineEdit::~QMultiLineEdit();
 }
 
 void CEdit::keyPressEvent(QKeyEvent*e)
 {
-    QMultiLineEdit::keyPressEvent(e);
+    QTextEdit::keyPressEvent(e);
     emit cursormove();
 }
 
 void CEdit::focusInEvent(QFocusEvent*e)
 {
-    QMultiLineEdit::focusInEvent(e);
+    QTextEdit::focusInEvent(e);
     emit cursormove();
 }
 
 void CEdit::mouseReleaseEvent(QMouseEvent*e)
 {
-    QMultiLineEdit::mouseReleaseEvent(e);
+    QTextEdit::mouseReleaseEvent(e);
     emit cursormove();
 }
