@@ -5,7 +5,7 @@
 #ifndef _edit_h
 #define _edit_h
 
-class CEdit : public virtual QMultiLineEdit
+class CEdit : public virtual QTextEdit
 {
     Q_OBJECT
 public:
