@@ -16,14 +16,14 @@
 #include "grantedit.h"
 #include "my_sql.h"
 #include "stringres.h"
-#include "settings.h"
+#include "kmysqladmin/setup/settings.h"
 #include "TabView.h"
 #include "qlistview.h"
 
 #include "stringres.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: granttable.cpp,v 2.19 2001/04/29 11:14:07 ral Exp $";
+static const char rcsid[]="$Id: granttable.cpp,v 2.23 2003/02/09 17:54:35 ral Exp $";
 //const char*granttable_rcs(){return rcsid;}
 #endif
 
@@ -49,20 +49,21 @@ const char*CGrantTable::No="N";
 
 #define Inherited CGrantTableData
 
+using namespace std;
+
 CGrantTable::CGrantTable(smart_pointer<CMySql>& _sql_server,QWidget* parent,const char* name)
     :Inherited( parent, name )
 {
     sql_server = _sql_server;
     QString caption;
-    User_Title=i18n(CStringRes::get_string(25));
-    DB_Title=i18n(CStringRes::get_string(26));
-    P_Title=i18n(CStringRes::get_string(27));
-    P2_Title=i18n(CStringRes::get_string(28));
-    caption = i18n(CStringRes::get_string(125));
-    caption += i18n(CStringRes::get_string(29));
+    User_Title=GET_TEXT(25);
+    DB_Title=GET_TEXT(26);
+    P_Title=GET_TEXT(27);
+    P2_Title=GET_TEXT(28);
+    caption = GET_TEXT(125);
+    caption += GET_TEXT(29);
     setCaption(caption);
     setIcon(kapp->icon());
-    //setMiniIcon(kapp->miniIcon());
     FontChanged();
     DisableButtons();
     ReadHostTable();
@@ -109,6 +110,7 @@ void CGrantTable::ReadHostTable()
     } else {
     }
     HostList->setCurrentItem(HostList->firstChild());
+    hosthilighted(HostList->firstChild());
     if (i == 0)
 	AddHostButton->setEnabled(TRUE);
 }
@@ -300,7 +302,7 @@ void CGrantTable::ModifyHost()
 	(*Patterns)[0].setIsNumeric(TRUE);
     erg.clear();
     erg.push_back(Host_Title);
-    erg.push_back(DB_Title);
+    erg.push_back(DB_Title.latin1());
     edit.set_entries(Patterns,&erg);
 
     if (edit.exec()) {
@@ -331,7 +333,7 @@ void CGrantTable::ModifyUser()
     PatternList*modify = 0;
     CPatternPair pat2;
     CGrantEdit edit(this);
-    edit.setCaption(CStringRes::get_string(30));//i18n("Edit User-Rights"));
+    edit.setCaption(GET_TEXT(30));
     int i = 0;
     int j = 0;
 
@@ -374,9 +376,9 @@ void CGrantTable::ModifyUser()
 
     erg.clear();
     erg.push_back(Host_Title);
-    erg.push_back(User_Title);
-    erg.push_back(P_Title);
-    erg.push_back(P2_Title);
+    erg.push_back(User_Title.latin1());
+    erg.push_back(P_Title.latin1());
+    erg.push_back(P2_Title.latin1());
     edit.set_entries(Patterns,&erg);
     erg.clear();
     j = DBList->childCount() > 0?0:1;
@@ -425,7 +427,7 @@ void CGrantTable::ModifyDb()
     PatternList*modify = 0;
     
     CGrantEdit edit(this);
-    edit.setCaption(CStringRes::get_string(31));//i18n("Edit DB-Rights"));
+    edit.setCaption(GET_TEXT(31));
 
     append_Sel(&erg);
     Patterns = break_dbstring();
@@ -450,8 +452,8 @@ void CGrantTable::ModifyDb()
     (*Patterns)[0].setIsNumeric(TRUE);
     erg.clear();
     erg.push_back(Host_Title);
-    erg.push_back(User_Title);
-    erg.push_back(DB_Title);
+    erg.push_back(User_Title.latin1());
+    erg.push_back(DB_Title.latin1());
     edit.set_entries(Patterns,&erg);
 
     if (edit.exec()) {
@@ -512,7 +514,7 @@ void CGrantTable::AddHost()
     Patterns->push_back(CPatternPair(DB_Table,""));
     
     erg.push_back(Host_Title);
-    erg.push_back(DB_Title);
+    erg.push_back(DB_Title.latin1());
     append_Add(Patterns);
     edit.set_entries(Patterns,&erg);
     delete Patterns; Patterns = 0;
@@ -569,9 +571,9 @@ void CGrantTable::AddUser()
     Patterns->push_back(CPatternPair(Fi_Str,No)); 
 
     erg.push_back(Host_Title);
-    erg.push_back(User_Title);
-    erg.push_back(P_Title);
-    erg.push_back(P2_Title);
+    erg.push_back(User_Title.latin1());
+    erg.push_back(P_Title.latin1());
+    erg.push_back(P2_Title.latin1());
     edit.set_entries(Patterns,&erg);
     erg.clear();
     delete Patterns; Patterns = 0;
@@ -588,14 +590,16 @@ void CGrantTable::AddUser()
 	    } else {
 		if (p1.size()) {
 		    sql_server->scramble_password(p1);
-		}
+		} else {
+                }
 		p_iter = Patterns->begin();
 		p_iter++;
 		Patterns->erase(p_iter);
 		p_iter = Patterns->begin();
 		p_iter++;
 		Patterns->erase(p_iter);
-		Patterns->insert(Patterns->begin(),CPatternPair(Pass_Entry,p1));
+                if (p1.size()) 
+                    Patterns->insert(Patterns->begin(),CPatternPair(Pass_Entry,p1));
 		Patterns->insert(Patterns->begin(),CPatternPair(Host_Table,Host));
 		i = sql_server->insert_row(DB_Name,User_Table,Patterns);
 		UpdateGrants(i);
@@ -635,8 +639,8 @@ void CGrantTable::AddDb()
         edit.setCaption(Title);
 
         titles.push_back(Host_Title);
-        titles.push_back(User_Title);
-        titles.push_back(DB_Title);
+        titles.push_back(User_Title.latin1());
+        titles.push_back(DB_Title.latin1());
         edit.set_entries(Patterns,&titles);
     
         delete Patterns; Patterns = 0;
