@@ -27,7 +27,7 @@
 #include "helpers/specials.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: my_sql.cpp,v 2.53 2003/02/04 00:08:53 ral Exp $";
+static const char rcsid[]="$Id: my_sql.cpp,v 2.54 2003/02/13 01:31:14 ral Exp $";
 #endif
 
 using namespace std;
@@ -1712,4 +1712,71 @@ bool CMySql::do_statement(const char*statement,stringlist&target,stringlist&size
     mysql_free_result(Res);
     return true;
 }
+
+bool CMySql::do_statement(const char*statement,list_vector&target,stringlist&headers,
+                          bool log_error_only)
+{
+    target.resize(0);
+    headers.resize(0);
+
+    if (!Sql_Connection) {
+	do_message(MessageArray[4]);
+	return false;	
+    }
+    MYSQL_ROW row;
+    MYSQL_FIELD*Field;
+
+    std::string query;
+    stringstream ss;
+
+    MYSQL_RES*Res=0;
+    if (!log_error_only)
+	do_message(statement);
+    int result = mysql_query(Sql_Connection,statement);
+    if (result < 0) {
+	if (log_error_only)
+	    do_message(statement);
+	do_message(get_last_error());
+	return false;
+    }
+    Res = mysql_store_result(Sql_Connection);
+    if (!Res) {
+        query = mysql_error(Sql_Connection);
+        if (!query.empty()) {
+	    if (log_error_only)
+		do_message(statement);
+            do_message(query.c_str());
+	    return false;
+	}
+        return true;
+    }
+    if (!log_error_only) {
+        unsigned long zaehler = Res->row_count;
+        ss.str("");
+        ss << zaehler << " " << MessageArray[0];
+	do_message(ss.str());
+    }
+    stringlist helper;
+    string f;
+    unsigned int j;
+    while ((row=mysql_fetch_row(Res))) {
+        helper.resize(0);
+        for (j = 0;j < mysql_num_fields(Res);++j) {
+	    query.resize(0);
+            query = row[j]?(char*)row[j]:"";
+            Res->current_field = j;
+            if (target.size()==0) {
+                Field = mysql_fetch_field(Res);
+                f = Field->name;
+		headers.push_back(std::string(f));
+            }
+	    helper.push_back(query);
+        }
+        //append to the list
+        target.push_back(helper);
+    }
+    mysql_free_result(Res);
+    return true;
+}
+
 #endif // HAVE_MYSQL_LIBS
