@@ -11,10 +11,13 @@ class CStringRes
 {
 protected:
     static const string_res res_array[];
+    std::string last_message;
 public:
-    CStringRes(){}
+    CStringRes(){last_message = "";}
     ~CStringRes(){}
     static const char*get_string(unsigned int id);
 };
 
+// for an easier use
+#define GET_TEXT(x) i18n(CStringRes::get_string(x))
 #endif
