@@ -30,19 +30,21 @@
 #include "tabledescr.h"
 #include "selectoutfile.h"
 #include "converter.h"
-#include "stringlist.h"
+#include "kmysqladmin/helpers/stringlist.h"
 #include "stringres.h"
-#include "smart_pointer.h"
+#include "kmysqladmin/helpers/smart_pointer.h"
 #include "progressdlg.h"
-#include "stringhelper.h"
-#include "settings.h"
+#include "kmysqladmin/helpers/stringhelper.h"
+#include "kmysqladmin/setup/settings.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: tableview.cpp,v 2.7 2001/04/29 11:14:07 ral Exp $";
+static const char rcsid[]="$Id: tableview.cpp,v 2.12 2003/02/09 17:54:35 ral Exp $";
 #endif
 
 #define Inherited CTableViewData
 
+using namespace std;
+
 CTableView::CTableView (smart_pointer<CMySql> & _sql_server,QWidget* parent,const char* name)
     :Inherited( parent, name,false,WType_TopLevel|WStyle_MinMax|WStyle_SysMenu|WStyle_NormalBorder )
 {
@@ -55,7 +57,7 @@ CTableView::CTableView (smart_pointer<CMySql> & _sql_server,QWidget* parent,cons
     // set all texts
     setCaption( GET_TEXT(76) );
     SelectTableLabel->setText( GET_TEXT(91) );
-    SelDbLabel->setText( GET_TEXT(90) );
+    SelDbLabel->setText( GET_TEXT(26) );
     SortByLabel->setText( GET_TEXT(92 ) );
     ModifyRow->setText( GET_TEXT(96) );
     saveButton->setText( GET_TEXT(99 ) );
@@ -86,7 +88,7 @@ CTableView::CTableView (smart_pointer<CMySql> & _sql_server,QWidget* parent,cons
     w = ws.toInt();
     h = hs.toInt();
     if (w && h) {
-	resize(w,h);
+        resize(w,h);
     }
     connect(&GlobalSettings,SIGNAL(fixfont_changed()),this,SLOT(FixFontChanged()));
     FixFontChanged();
@@ -106,11 +108,11 @@ void CTableView::RefreshLists()
     sql_server->get_db_list("%",list);
     if (!list.size()) {
         SelectDB->setEnabled(false);
-	return;
+        return;
     }
     SelectDB->setEnabled(true);
     for (stringlist::iterator iter = list.begin();iter != list.end();++iter) {
-	SelectDB->insertItem(iter->c_str());
+        SelectDB->insertItem(iter->c_str());
     }
     db_select(0);
 }
@@ -131,25 +133,25 @@ void CTableView::db_select(int i)
     s = SelectDB->text(i);
     if ( !SelectDB->isEnabled() || s.isEmpty()) {
         TableSelect->setEnabled(false);
-	return;
+        return;
     }
     stringlist Result;
     sql_server->get_table_list("%",s,Result);
     TableSelect->clear();
     if (Result.size() == 0) {
-	table_select(-1);
-	TableSelect->setEnabled(false);
-	return;
+        table_select(-1);
+        TableSelect->setEnabled(false);
+        return;
     } else {
-	TableSelect->setEnabled(true);
+        TableSelect->setEnabled(true);
     }
     if (sql_server->is_system_db(s)) {
-	EmptyTableButton->setEnabled(false);
+        EmptyTableButton->setEnabled(false);
     } else {
-	EmptyTableButton->setEnabled(true);
+        EmptyTableButton->setEnabled(true);
     }
     for (stringlist::iterator iter=Result.begin();iter!=Result.end();++iter) {
-	TableSelect->insertItem(iter->c_str());
+        TableSelect->insertItem(iter->c_str());
     }
     table_select(0);
 }
@@ -170,27 +172,27 @@ void CTableView::table_select(int i)
     QString t = SelectDB->currentText();
 
     if (s.isEmpty() || t.isEmpty()) {
-	set_buttons(FALSE);
-	ColumnDisplay->setEnabled(false);
-	ColumnDisplay->update();
-	SortListBox->setEnabled(false);
-	return;
+        set_buttons(FALSE);
+        ColumnDisplay->setEnabled(false);
+        ColumnDisplay->update();
+        SortListBox->setEnabled(false);
+        return;
     }
     sql_server->get_table_keys(t,s,CurrentKeys);
     if (!sql_server->get_table_fields(t,s,Current_Table_Fields) || Current_Table_Fields.size()==0) {
-	SortListBox->setEnabled(false);
-	ColumnDisplay->setEnabled(false);
-	set_buttons(FALSE);
-	return;
+        SortListBox->setEnabled(false);
+        ColumnDisplay->setEnabled(false);
+        set_buttons(FALSE);
+        return;
     }
     SortListBox->setEnabled(true);
     ColumnDisplay->setEnabled(true);
     int count = 0;
     for (ergebnis = Current_Table_Fields.begin();ergebnis!=Current_Table_Fields.end(); ++ergebnis){
-	ColumnDisplay->insertItem(ergebnis->get_name());
-	SortListBox->insertItem(ergebnis->get_name());
+        ColumnDisplay->insertItem(ergebnis->get_name());
+        SortListBox->insertItem(ergebnis->get_name());
         OutputList->addColumn(ergebnis->get_name());
-	++count;
+        ++count;
     }
     Current_Displayed_Fields = Current_Table_Fields;
     set_buttons(TRUE);
@@ -209,32 +211,32 @@ void CTableView::addRow()
     table = TableSelect->currentText();
     db = SelectDB->currentText();
     for (Field = Current_Table_Fields.begin();Field != Current_Table_Fields.end();++Field) {
-	if (!Field->is_AutoIncrement() ) {
-	    e_PatternIterator iter;
-	    which.push_back(e_patternpair(Field->get_name(),Field->get_default()));
-	    iter = which.end();
-	    iter--;
-	    iter->setIsNumeric(Field->is_Numeric());
-	    iter->setLargeText(Field->is_Blob());
-	    stringIlist _temp_list = Field->enum_list();
-	    if (_temp_list.size()>0) {
-		if (!Field->is_NotNull())
-		    _temp_list.insert(_temp_list.begin(),"");
-		iter->set_enumlist(_temp_list);
-	    }
-	}
+        if (!Field->is_AutoIncrement() ) {
+            e_PatternIterator iter;
+            which.push_back(e_patternpair(Field->get_name(),Field->get_default()));
+            iter = which.end();
+            iter--;
+            iter->setIsNumeric(Field->is_Numeric());
+            iter->setLargeText(Field->is_Blob());
+            stringIlist _temp_list = Field->enum_list();
+            if (_temp_list.size()>0) {
+                if (!Field->is_NotNull())
+                    _temp_list.insert(_temp_list.begin(),"");
+                iter->set_enumlist(_temp_list);
+            }
+        }
     }
     edit.setCaption(GET_TEXT(77));
     edit.build_widgets(&which);
     if (edit.exec())
         result = edit.get_entries(FALSE);
     else
-	return;
+        return;
     if (!result)
-	return;
+        return;
     i = sql_server->insert_row(db,table,result);
     if (i < 0) {
-	display_error_box();
+        display_error_box();
     }
     delete result;
 }
@@ -278,35 +280,35 @@ void CTableView::modifyRow()
     i = BreakIntoParts(&_BreakList,&KeyList);
 
     if (i < 0 || _BreakList.size() == 0 || KeyList.size() == 0) {
-	return;
+        return;
     }
     for (unsigned j = 0;j < _BreakList.size();++j) {
-	BreakList.push_back(_BreakList[j]);
-	for (unsigned a=0;a<Current_Displayed_Fields.size();++a) {
-	    if ( strcasecmp(BreakList[j].get_entry(),Current_Displayed_Fields[a].get_name()) == 0) {
-		stringIlist _temp_list = Current_Displayed_Fields[a].enum_list();
-		if (_temp_list.size()>0) {
-		    if (!Current_Displayed_Fields[a].is_NotNull())
-			_temp_list.insert(_temp_list.begin(),"");
-		    BreakList[j].set_enumlist(_temp_list);
-		}
-		break;
-	    }
-	}
+        BreakList.push_back(_BreakList[j]);
+        for (unsigned a=0;a<Current_Displayed_Fields.size();++a) {
+            if ( strcasecmp(BreakList[j].get_entry(),Current_Displayed_Fields[a].get_name()) == 0) {
+                stringIlist _temp_list = Current_Displayed_Fields[a].enum_list();
+                if (_temp_list.size()>0) {
+                    if (!Current_Displayed_Fields[a].is_NotNull())
+                        _temp_list.insert(_temp_list.begin(),"");
+                    BreakList[j].set_enumlist(_temp_list);
+                }
+                break;
+            }
+        }
     }
     edit.build_widgets(&BreakList);
 
     edit.setCaption("Modify");
     if (!edit.exec()) {
-	return;
+        return;
     }
 
     ModList = edit.get_entries(true);
 
     if (!ModList || ModList->size() == 0) {
-	if (ModList)
-	    delete ModList;
-	return;	
+        if (ModList)
+            delete ModList;
+        return;    
     }
     e_PatternIterator break_iter;
     PatternIterator mod_iter;
@@ -314,27 +316,27 @@ void CTableView::modifyRow()
     break_iter = BreakList.begin();
     mod_iter = ModList->begin();
     while (break_iter!=BreakList.end()) {
-	Entry = mod_iter->get_pattern();
-	Breaks = break_iter->get_pattern();
-	if (Breaks == Entry) {
-	    mod_iter =  ModList->erase(mod_iter);
-	} else {
-	    ++mod_iter;
-	}
-	++break_iter;
+        Entry = mod_iter->get_pattern();
+        Breaks = break_iter->get_pattern();
+        if (Breaks == Entry) {
+            mod_iter =  ModList->erase(mod_iter);
+        } else {
+            ++mod_iter;
+        }
+        ++break_iter;
     }
     if (ModList->size() == 0) {
-	delete ModList;
-	return;	
+        delete ModList;
+        return;    
     }
     i = sql_server->update_row(SelectDB->currentText(),TableSelect->currentText(),
-		       ModList,&KeyList);
+                               ModList,&KeyList);
     delete ModList;
 
     if (i < 0) {
-	display_error_box();
+        display_error_box();
     } else
-	MakeRequest();
+        MakeRequest();
 }
 
 void CTableView::delete_row()
@@ -342,18 +344,18 @@ void CTableView::delete_row()
     PatternList KeyList;
     int i = BreakIntoParts(0,&KeyList);
     if (i < 0 || KeyList.size() == 0) {
-	return;
+        return;
     }
     i = KMessageBox::questionYesNo(this,GET_TEXT(80),
                                    GET_TEXT(79));
     if (i == KMessageBox::No) {
-	return;
+        return;
     }
     i = sql_server->delete_row(SelectDB->currentText(),TableSelect->currentText(),&KeyList);
     if (i < 0) {
-	display_error_box();
+        display_error_box();
     } else {
-	MakeRequest();
+        MakeRequest();
     }
 }
 
@@ -366,11 +368,11 @@ void CTableView::emptyTable()
     message+="\n";
     int i = KMessageBox::questionYesNo (this, message, GET_TEXT(82));
     if (i == KMessageBox::No)
-	return;
+        return;
     i = sql_server->delete_row(SelectDB->currentText(),TableSelect->currentText());
     if (i < 0) {
-	display_error_box();
-	return;
+        display_error_box();
+        return;
     }
     OutputList->clear();
     ModifyRow->setEnabled(false);
@@ -383,30 +385,31 @@ bool CTableView::KeyDisplayed()
 {
     
     if (SelectFields.size()==0) {
-	return false;
+        return false;
     }
     return true;
 }
 
-CColumnDescriptor*CTableView::FindTableItem(const char*what,bool all_fields)
+ColumnList_iterator CTableView::FindTableItem(const char*what,bool all_fields)
 {
-    ColumnList_iterator Entry;
+    vector<CColumnDescriptor>::iterator Entry;
     if (all_fields) {
-	for (Entry = Current_Table_Fields.begin();Entry!=Current_Table_Fields.end();++Entry) {
-	    if (*Entry == what)
-		return Entry;
-	}
+        for (Entry = Current_Table_Fields.begin();Entry!=Current_Table_Fields.end();++Entry) {
+            if (*Entry == what)
+                return Entry;
+        }
+        return Entry;
     } else {
-	for (Entry = Current_Displayed_Fields.begin();Entry!=Current_Displayed_Fields.end();++Entry) {
-	    if (*Entry == what)
-		return Entry;
-	}
+        for (Entry = Current_Displayed_Fields.begin();Entry!=Current_Displayed_Fields.end();++Entry) {
+            if (*Entry == what)
+                return Entry;
+        }
+        return Entry;
     }
-    return NULL;
 }
 
 int CTableView::BreakIntoParts(PatternList*BreakList,PatternList*KeyList,QListViewItem*item,
-			       bool no_auto_filter)
+                               bool no_auto_filter)
 {
     ColumnList_iterator Field;
     QListViewItem*current_item;
@@ -414,14 +417,14 @@ int CTableView::BreakIntoParts(PatternList*BreakList,PatternList*KeyList,QListVi
     int i = 0;
 
     if (Current_Displayed_Fields.size() == 0)
-	return -1;
+        return -1;
     if (item == 0) 
         current_item = OutputList->selectedItem();
     else
-	current_item = item;
+        current_item = item;
 
     if (!current_item)
-	return -1;
+        return -1;
 
     for (i = 0; i < OutputList->columns();++i) {
         if (BreakList)
@@ -429,34 +432,34 @@ int CTableView::BreakIntoParts(PatternList*BreakList,PatternList*KeyList,QListVi
         if (KeyList)
             KeyList->push_back(CPatternPair("",current_item->text(i).latin1()));
     }
-    PatternIterator break_iterator = 0;
-    PatternIterator key_iterator = 0;
+    PatternIterator break_iterator;// = BreakList->end();
+    PatternIterator key_iterator;// = KeyList->end();
     if (BreakList)
-	break_iterator = BreakList->begin();
+        break_iterator = BreakList->begin();
     if (KeyList)
-	key_iterator= KeyList->begin();
+        key_iterator= KeyList->begin();
     for (Field = Current_Displayed_Fields.begin();Field!=Current_Displayed_Fields.end();++Field) {
-	if (BreakList) {
-	    if (Field->is_AutoIncrement() && !no_auto_filter) {
-		break_iterator = BreakList->erase(break_iterator);
-	    } else {
-		if (break_iterator) {
-		    break_iterator->set_entry(Field->get_name());
-		    break_iterator->setLargeText(Field->is_Blob());
-		    ++break_iterator;
-		}
-	    }
-	}
-	if (KeyList) {
-	    if (SelectFields.find(Field->get_name())) {
-		if (key_iterator) {
-		    key_iterator->set_entry(Field->get_name());
-		    ++key_iterator;
-		}
-	    } else {
-		key_iterator = KeyList->erase(key_iterator);
-	    }
-	}
+        if (BreakList) {
+            if (Field->is_AutoIncrement() && !no_auto_filter) {
+                break_iterator = BreakList->erase(break_iterator);
+            } else {
+                if (break_iterator!=BreakList->end()) {
+                    break_iterator->set_entry(Field->get_name());
+                    break_iterator->setLargeText(Field->is_Blob());
+                    ++break_iterator;
+                }
+            }
+        }
+        if (KeyList) {
+            if (SelectFields.find(Field->get_name())!=SelectFields.end()) {
+                if (key_iterator!=KeyList->end()) {
+                    key_iterator->set_entry(Field->get_name());
+                    ++key_iterator;
+                }
+            } else {
+                key_iterator = KeyList->erase(key_iterator);
+            }
+        }
     }
 
     return 0;
@@ -470,68 +473,71 @@ void CTableView::saveResult()
     QFileInfo finfo;
     int i;
     if (OutputList->childCount() == 0)
-	return;
+        return;
     if (!SelectBox.exec())
-	return;
+        return;
     filename = SelectBox.get_name();
     if (filename.isEmpty())
-	return;
+        return;
     finfo.setFile(filename);
     if (finfo.isDir()) {
-	QMessageBox::warning(this,GET_TEXT(83),
-			     GET_TEXT(84));
-	return;
+        QMessageBox::warning(this,GET_TEXT(83),
+                             GET_TEXT(84));
+        return;
     }
     if (QFile::exists(filename)) {
-	message = GET_TEXT(85);
-	message+="\n\n";
-	message+=filename;message+="\n\n";
-	message+=GET_TEXT(86);
-	message+="\n";
-	i = KMessageBox::questionYesNo( this,message, GET_TEXT(87));
-	if (i == KMessageBox::No )
-	    return;
+        message = GET_TEXT(85);
+        message+="\n\n";
+        message+=filename;message+="\n\n";
+        message+=GET_TEXT(86);
+        message+="\n";
+        i = KMessageBox::questionYesNo( this,message, GET_TEXT(87));
+        if (i == KMessageBox::No )
+            return;
 
-	if (!finfo.isWritable()) {
-	    QMessageBox::warning(this,GET_TEXT(83),
-				GET_TEXT(88));
-	    return;
-	}
+        if (!finfo.isWritable()) {
+            QMessageBox::warning(this,GET_TEXT(83),
+                                 GET_TEXT(88));
+            return;
+        }
     }
     i = SelectBox.get_type();
+    cout << "Select: " << i << "\n";
     switch (i) {
     case 1:
-	saveHtml(filename);
-	break;
+        saveAscii(filename,";");
+        break;
     case 2:
-	saveLatex(filename);
-	break;
+        saveHtml(filename);
+        break;
+    case 3:
+        saveLatex(filename);
+        break;
     default:
-	saveAscii(filename);
+        saveAscii(filename);
     }
 }
 
-void CTableView::saveAscii(const char*filename)
+void CTableView::saveAscii(const char*filename,const char*aSep)
 {
     int j = 0;
-    QString line = "";
-    QString entry;
-    QString Breaks;
+    
+    const char*sep = aSep?aSep:"\t";
+
     if (!filename || strlen(filename) == 0)
-	return;
+        return;
     if (OutputList->childCount() < 1)
-	return;
+        return;
     QFile outfile(filename);
     outfile.open(IO_WriteOnly|IO_Truncate);
     if (!outfile.isOpen()) 
-	return;
+        return;
     QTextStream st(&outfile);
     QListViewItemIterator it(OutputList);
 
     for (; it.current();++it) {
-        //        st << "| ";
         for (j = 0; j < OutputList->columns();++j) {
-            st << (j == 0?"":"\t");
+            st << (j == 0?"":sep);
             st << it.current()->text(j);
         }
         st << "\n";
@@ -543,57 +549,57 @@ void CTableView::saveHtml(const char*filename)
 {
     smart_pointer<CConverter> converter(CConverter::get_converter(CConverter::HTML));
     if (!converter)
-	return;
+        return;
     PatternList*KeyList = 0;
     PatternIterator key_iterator;
     ColumnList_iterator desc;
     QString entry;
 
     if (!filename || strlen(filename) == 0)
-	return;
+        return;
     if (OutputList->childCount() < 1)
-	return;
+        return;
     QFile outfile(filename);
     outfile.open(IO_WriteOnly|IO_Truncate);
     if (!outfile.isOpen()) 
-	return;
+        return;
     QTextStream st(&outfile);
     st << "<HTML>\n<HEAD>\n<TITLE>TableOutput</TITLE>\n</HEAD>\n";
     st << "<BODY>\n<TABLE WIDTH=100% BORDER=1 CELLPADDING=3 CELLSPACING=1>\n";
     st << "  <TR VALIGN=TOP>\n";
     for (desc = Current_Displayed_Fields.begin();desc!= Current_Displayed_Fields.end();++desc) {
-	st << "    <TH><P>" << desc->get_name() << "</TH>\n";
+        st << "    <TH><P>" << desc->get_name() << "</TH>\n";
     }
     st << "  </TR>\n";
     KeyList = new PatternList;
     QListViewItemIterator it(OutputList);
 
     for (; it.current();++it) {
-	KeyList->resize(0);
-	BreakIntoParts(KeyList,0,it.current(),true);
-	st << "  <TR>\n";
-	desc = Current_Displayed_Fields.begin();
-	key_iterator = KeyList->begin();
-	for (key_iterator = KeyList->begin();key_iterator != KeyList->end();++key_iterator) {
-	    if (desc && desc->is_Numeric())
-		st << "    <TD><P ALIGN=RIGHT>";
-	    else
-		st << "    <TD><P>";
-	    entry = key_iterator->get_pattern();
-	    if (entry.length() > 0) {
-		st << converter->convert(entry);
-	    }
-	    else {
-		entry = "<br>";
-		st << entry;
-	    }
-	    st << "</TD>\n";
-	    ++desc;
-	}
-	st << "  </TR>\n";
+        KeyList->resize(0);
+        BreakIntoParts(KeyList,0,it.current(),true);
+        st << "  <TR>\n";
+        desc = Current_Displayed_Fields.begin();
+        key_iterator = KeyList->begin();
+        for (key_iterator = KeyList->begin();key_iterator != KeyList->end();++key_iterator) {
+            if (desc!=Current_Displayed_Fields.end() && desc->is_Numeric())
+                st << "    <TD><P ALIGN=RIGHT>";
+            else
+                st << "    <TD><P>";
+            entry = key_iterator->get_pattern();
+            if (entry.length() > 0) {
+                st << converter->convert(entry);
+            }
+            else {
+                entry = "<br>";
+                st << entry;
+            }
+            st << "</TD>\n";
+            ++desc;
+        }
+        st << "  </TR>\n";
     }
     st << "</TABLE>\n<P>\n<FONT SIZE=-1>\n"
-	"Document created with KMySqlAdmin\n</FONT>\n</BODY>\n</HTML>\n";
+        "Document created with KMySqlAdmin\n</FONT>\n</BODY>\n</HTML>\n";
     delete KeyList;
 }
 
@@ -602,7 +608,7 @@ void CTableView::saveLatex(const char*filename)
     PatternList BreakList;
     smart_pointer<CConverter> converter(CConverter::get_converter(CConverter::LATEX));
     if (!converter)
-	return;
+        return;
     ColumnList_iterator desc;
     std::string entry;
     std::string head, head2, head3;
@@ -610,13 +616,13 @@ void CTableView::saveLatex(const char*filename)
     unsigned int j;
     
     if (!filename || strlen(filename) == 0)
-	return;
+        return;
     if (OutputList->childCount() < 1)
-	return;
+        return;
     ofstream st(filename);
     if (!st) {
-	QMessageBox::critical(this,GET_TEXT(112),GET_TEXT(83));
-	return;
+        QMessageBox::critical(this,GET_TEXT(112),GET_TEXT(83));
+        return;
     }
     unsigned int with = Current_Displayed_Fields.size();
     st << "\\documentclass[10pt,a4paper]{article}\n";
@@ -629,23 +635,23 @@ void CTableView::saveLatex(const char*filename)
     head3 = "";
     for (desc = Current_Displayed_Fields.begin();desc!= Current_Displayed_Fields.end();++desc ) {
         if (desc != Current_Displayed_Fields.begin()) {
-	    head3+=" & ";
-	}
-	string dummy = converter->convert(desc->get_name());
-	if (!dummy.empty()) {
-	    head3+="\\tabcenter{\\bf ";
-	    head3+=dummy;
-	    head3+="}";
-	}
-	else {
-	    head3+=" ";
-	}
+            head3+=" & ";
+        }
+        string dummy = converter->convert(desc->get_name());
+        if (!dummy.empty()) {
+            head3+="\\tabcenter{\\bf ";
+            head3+=dummy;
+            head3+="}";
+        }
+        else {
+            head3+=" ";
+        }
     }
     head3 += "\\\\ \\hline\n";
 
     head = "\\begin{longtable}{|";
     for (i  = 0;i < Current_Displayed_Fields.size();++i ) {
-	head+="l|";
+        head+="l|";
     }
     head+="}\n\\caption*{\\bf Database: ";
     head+=converter->convert(SelectDB->currentText());
@@ -677,21 +683,21 @@ void CTableView::saveLatex(const char*filename)
     QListViewItemIterator it(OutputList);
 
     for (; it.current();++it) {
-	BreakList.resize(0);
-	prg.setPos(i);
-	BreakIntoParts(&BreakList,0,it.current(),true);
-	for (break_iterator=BreakList.begin();break_iterator!=BreakList.end();++break_iterator) {
-	    if (break_iterator != BreakList.begin())
-		st << " & ";
-	    QString dummy = converter->convert(break_iterator->get_pattern());
-	    if (!dummy.isEmpty()) {
-		st << dummy;
-	    }
-	    else {
-		st << " ";
-	    }
-	}
-	st << "\\\\ \\hline\n";
+        BreakList.resize(0);
+        prg.setPos(i);
+        BreakIntoParts(&BreakList,0,it.current(),true);
+        for (break_iterator=BreakList.begin();break_iterator!=BreakList.end();++break_iterator) {
+            if (break_iterator != BreakList.begin())
+                st << " & ";
+            QString dummy = converter->convert(break_iterator->get_pattern());
+            if (!dummy.isEmpty()) {
+                st << dummy;
+            }
+            else {
+                st << " ";
+            }
+        }
+        st << "\\\\ \\hline\n";
     }
     st << "\\end{longtable}\n%ready with table\n\n";
     st << "\\end{document}\n";
@@ -704,34 +710,34 @@ void CTableView::build_relevant_keys()
     SelectFields.resize(0);
     unsigned int count;
     if (!Current_Displayed_Fields.size() || !CurrentKeys.size()) {
-	return;
+        return;
     }
     KeyList::iterator k_iterator = CurrentKeys.begin();
     while(k_iterator != CurrentKeys.end()) {
-	if (!k_iterator->is_UniqueKey()) {
-	    CurrentKeys.erase(k_iterator);
-	} else {
-	    ++k_iterator;
-	}
+        if (!k_iterator->is_UniqueKey()) {
+            CurrentKeys.erase(k_iterator);
+        } else {
+            ++k_iterator;
+        }
     }
     if (!CurrentKeys.size()) {
-	return;
+        return;
     }
     for(k_iterator=CurrentKeys.begin();k_iterator!=CurrentKeys.end();++k_iterator) {
-	all_found = true;
-	e_list = k_iterator->get_ColList();
-	for (count = 0;count < e_list.size();++count) {
-	    all_found = FindTableItem(e_list[count].first.c_str(),false) != 0;
-	    if (!all_found)
-		break;
-	}
-	if (all_found) {
-	    for (count = 0; count < e_list.size();++count) {
-		if (! SelectFields.find(e_list[count].first)) {
-		    SelectFields.push_back(e_list[count].first);
-		}
-	    }
-	}
+        all_found = true;
+        e_list = k_iterator->get_ColList();
+        for (count = 0;count < e_list.size();++count) {
+            all_found = FindTableItem(e_list[count].first.c_str(),false) != Current_Table_Fields.end();
+            if (!all_found)
+                break;
+        }
+        if (all_found) {
+            for (count = 0; count < e_list.size();++count) {
+                if (SelectFields.find(e_list[count].first)==SelectFields.end()) {
+                    SelectFields.push_back(e_list[count].first);
+                }
+            }
+        }
     }
 }
 
@@ -762,64 +768,67 @@ void CTableView::_make_fetch_request(bool search_it)
     }
     Current_Displayed_Fields.resize(0);
     if (SortListBox->count() == 0) {
-	return;
+        return;
     }
     sort = SortListBox->currentText();
     for (id = 0; id < ColumnDisplay->count();id++) {
-	if (ColumnDisplay->isSelected(id)) {
+        if (ColumnDisplay->isSelected(id)) {
             QString s_ = ColumnDisplay->text(id);
-	    which.push_back(s_.latin1());
-	    Field = FindTableItem(s_.latin1());
-	    if (Field) {
-		Current_Displayed_Fields.push_back(*Field);
-	    }
-	}
+            which.push_back(s_.latin1());
+            Field = FindTableItem(s_.latin1());
+            /*
+             * In this case we only search all fields so it is correct!
+             */
+            if (Field!=Current_Table_Fields.end()) {
+                Current_Displayed_Fields.push_back(*Field);
+            }
+        }
     }
     if (Current_Displayed_Fields.size() == 0) {
-	for (Field = Current_Table_Fields.begin();Field!=Current_Table_Fields.end();++Field) {
-	    Current_Displayed_Fields.push_back(CColumnDescriptor(*Field));
-	}  
+        for (Field = Current_Table_Fields.begin();Field!=Current_Table_Fields.end();++Field) {
+            Current_Displayed_Fields.push_back(CColumnDescriptor(*Field));
+        }  
     }
     build_relevant_keys();
 
     if (search_it) {
-	for (Field = Current_Table_Fields.begin();Field != Current_Table_Fields.end();++Field) {
-	    e_PatternIterator p_iter;
-	    pattern_list.push_back(e_patternpair(Field->get_name(),""));
-	    p_iter = pattern_list.end();
-	    --p_iter;
-	    p_iter->setIsNumeric(Field->is_Numeric());
-	    p_iter->setLargeText(Field->is_Blob());
-	    stringIlist _temp_enums = Field->enum_list();
-	    if (_temp_enums.size() > 0) {
-		// we requires the empy one, too
-		_temp_enums.insert(_temp_enums.begin(),"");
-		p_iter->set_enumlist(_temp_enums);
-	    }
-	}
-	edit.setCaption(GET_TEXT(78));
-	edit.build_widgets(&pattern_list);
-	if (edit.exec()) {
-	    result = edit.get_entries(FALSE);
-	} else {
-	    return;
-	}
+        for (Field = Current_Table_Fields.begin();Field != Current_Table_Fields.end();++Field) {
+            e_PatternIterator p_iter;
+            pattern_list.push_back(e_patternpair(Field->get_name(),""));
+            p_iter = pattern_list.end();
+            --p_iter;
+            p_iter->setIsNumeric(Field->is_Numeric());
+            p_iter->setLargeText(Field->is_Blob());
+            stringIlist _temp_enums = Field->enum_list();
+            if (_temp_enums.size() > 0) {
+                // we requires the empy one, too
+                _temp_enums.insert(_temp_enums.begin(),"");
+                p_iter->set_enumlist(_temp_enums);
+            }
+        }
+        edit.setCaption(GET_TEXT(78));
+        edit.build_widgets(&pattern_list);
+        if (edit.exec()) {
+            result = edit.get_entries(FALSE);
+        } else {
+            return;
+        }
     }
 
     i = 0;
 
     for (Field = Current_Displayed_Fields.begin();Field!=Current_Displayed_Fields.end();++Field) {
-	OutputList->addColumn(Field->get_name());
-	++i;
+        OutputList->addColumn(Field->get_name());
+        ++i;
     }
     stringlist SizePattern;
     i = sql_server->fetch_rows(db,table,sort,&which,erg,
-			       (unsigned)OffsetEdit->value(),
-			       (unsigned)LimitEdit->value(),result);
+                               (unsigned)OffsetEdit->value(),
+                               (unsigned)LimitEdit->value(),result);
 
     if (result) {
-	delete result;
-	result = 0;
+        delete result;
+        result = 0;
     }
     timeval starttime,endtime; 
     KApplication::kApplication()->processEvents(100);
@@ -833,12 +842,12 @@ void CTableView::_make_fetch_request(bool search_it)
     unsigned int max_count = OutputList->columns();
     unsigned int count;
     if (erg.size() > 4999) {
-	CProgressDlg prg(0,erg.size(),"Inserting data into table view",0,"ProgressDlg");
-	prg.show();
-	for (;erg_iter != erg.end();++erg_iter) {
+        CProgressDlg prg(0,erg.size(),"Inserting data into table view",0,"ProgressDlg");
+        prg.show();
+        for (;erg_iter != erg.end();++erg_iter) {
             siter = erg_iter->begin();
             item = new QListViewItem(OutputList,item);
-	    prg.setPos(++running);
+            prg.setPos(++running);
             count = 0;
             for (;siter!=erg_iter->end();++siter) {
                 item->setText(count,siter->c_str());
@@ -846,10 +855,10 @@ void CTableView::_make_fetch_request(bool search_it)
                 if (count == max_count)
                     break;
             }
-	}
-	prg.hide();
+        }
+        prg.hide();
     } else {
-	for (;erg_iter != erg.end();++erg_iter) {
+        for (;erg_iter != erg.end();++erg_iter) {
             siter = erg_iter->begin();
             item = new QListViewItem(OutputList,item);
             count = 0;
@@ -859,15 +868,15 @@ void CTableView::_make_fetch_request(bool search_it)
                 if (count == max_count)
                     break;
             }
-	}
+        }
     }
 #else
     int intiter = 0;
     int count_rows = OutputList->numRows();
-    debug("Enthaelt bereits %i Zeilen",count_rows);
+    debug("Enthaelt bereits %i Zeilen\n",count_rows);
     if (erg.size()>4999) {
-	CProgressDlg prg(0,erg.size(),"Inserting data into table view",0,"ProgressDlg");
-	prg.show();
+        CProgressDlg prg(0,erg.size(),"Inserting data into table view",0,"ProgressDlg");
+        prg.show();
         for (;intiter<erg.size();++intiter) {
             //prg.SetPos((int)intiter);
             if (intiter<count_rows) {
@@ -899,7 +908,7 @@ void CTableView::_make_fetch_request(bool search_it)
      
     //hope you'll never see it
     if (i < 0) {
-	display_error_box();
+        display_error_box();
     }
     OutputList->setSelected(OutputList->firstChild(),true);
     OutputList->setFocus();
@@ -909,15 +918,15 @@ bool CTableView::close( bool forceKill)
 {
     KConfig * k = KGlobal::config();
     if (k) {
-	k->setGroup("table_view");
-	int w,h;
-	w = width();
-	h = height();
-	QString s;
-	s.setNum(w);
-	k->writeEntry("width",s);
-	s.setNum(h);
-	k->writeEntry("height",s);
+        k->setGroup("table_view");
+        int w,h;
+        w = width();
+        h = height();
+        QString s;
+        s.setNum(w);
+        k->writeEntry("width",s);
+        s.setNum(h);
+        k->writeEntry("height",s);
     }
     return CTableViewData::close(forceKill);
 }
